@@ -17,49 +17,48 @@
 
 #include "config/generalpagewidget.h"
 
-#include "backend/corebackendmanager.h"
+#include <kpmcore/backend/corebackendmanager.h>
+#include <kpmcore/fs/filesystemfactory.h>
 
-#include "fs/filesystem.h"
-#include "fs/filesystemfactory.h"
-
-#include "util/helpers.h"
+#include <kpmcore/util/helpers.h>
+#include "util/guihelpers.h"
 
 #include <config.h>
 
 GeneralPageWidget::GeneralPageWidget(QWidget* parent) :
-	QWidget(parent)
+    QWidget(parent)
 {
-	setupUi(this);
-	setupDialog();
+    setupUi(this);
+    setupDialog();
 }
 
 FileSystem::Type GeneralPageWidget::defaultFileSystem() const
 {
-	return FileSystem::typeForName(comboDefaultFileSystem().currentText());
+    return FileSystem::typeForName(comboDefaultFileSystem().currentText());
 }
 
 void GeneralPageWidget::setDefaultFileSystem(FileSystem::Type t)
 {
-	const int idx = comboDefaultFileSystem().findText(FileSystem::nameForType(t));
-	comboDefaultFileSystem().setCurrentIndex(idx != -1 ? idx : 0);
+    const int idx = comboDefaultFileSystem().findText(FileSystem::nameForType(t));
+    comboDefaultFileSystem().setCurrentIndex(idx != -1 ? idx : 0);
 }
 
 void GeneralPageWidget::setupDialog()
 {
-	QStringList fsNames;
-	foreach (const FileSystem* fs, FileSystemFactory::map())
-		if (fs->supportCreate() != FileSystem::cmdSupportNone && fs->type() != FileSystem::Extended)
-			fsNames.append(fs->name());
+    QStringList fsNames;
+    foreach(const FileSystem * fs, FileSystemFactory::map())
+    if (fs->supportCreate() != FileSystem::cmdSupportNone && fs->type() != FileSystem::Extended)
+        fsNames.append(fs->name());
 
-	qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
+    qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-	foreach (const QString& fsName, fsNames)
-		comboDefaultFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
+    foreach(const QString & fsName, fsNames)
+    comboDefaultFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
-	setDefaultFileSystem(FileSystem::defaultFileSystem());
+    setDefaultFileSystem(GuiHelpers::defaultFileSystem());
 
-	kcfg_shredSource->setId(radioButton, 0);
-	kcfg_shredSource->setId(radioButton_2, 1);
-	radioButton->setChecked(Config::shredSource() == Config::EnumShredSource::random);
-	radioButton_2->setChecked(Config::shredSource() == Config::EnumShredSource::zeros);
+    kcfg_shredSource->setId(radioButton, 0);
+    kcfg_shredSource->setId(radioButton_2, 1);
+    radioButton->setChecked(Config::shredSource() == Config::EnumShredSource::random);
+    radioButton_2->setChecked(Config::shredSource() == Config::EnumShredSource::zeros);
 }
