@@ -17,79 +17,76 @@
 
 #include "gui/listdevices.h"
 
-#include "core/device.h"
+#include <kpmcore/core/device.h>
 
-#include "util/globallog.h"
-#include "util/capacity.h"
+#include <kpmcore/util/globallog.h>
+#include <kpmcore/util/capacity.h>
 
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
 
 class ListDeviceWidgetItem : public QListWidgetItem
 {
-	public:
-		ListDeviceWidgetItem(const Device& d) :
-			QListWidgetItem(QIcon(KIconLoader().loadIcon(d.iconName(), KIconLoader::Desktop)), d.prettyName()),
-			deviceNode(d.deviceNode())
-		{
-			setToolTip(d.prettyName());
-			setSizeHint(QSize(0, 32));
-		}
+public:
+    ListDeviceWidgetItem(const Device& d) :
+        QListWidgetItem(QIcon::fromTheme(d.iconName()).pixmap(IconSize(KIconLoader::Desktop)), d.prettyName()),
+        deviceNode(d.deviceNode()) {
+        setToolTip(d.prettyName());
+        setSizeHint(QSize(0, 32));
+    }
 
-		const QString deviceNode;
+    const QString deviceNode;
 };
 
 /** Creates a new ListDevices instance.
-	@param parent the parent widget
+    @param parent the parent widget
 */
 ListDevices::ListDevices(QWidget* parent) :
-	QWidget(parent),
-	Ui::ListDevicesBase(),
-	m_ActionCollection(NULL)
+    QWidget(parent),
+    Ui::ListDevicesBase(),
+    m_ActionCollection(NULL)
 {
-	setupUi(this);
+    setupUi(this);
 }
 
 void ListDevices::updateDevices(OperationStack::Devices& devices)
 {
-	listDevices().clear();
+    listDevices().clear();
 
-	foreach(const Device* d, devices)
-		listDevices().addItem(new ListDeviceWidgetItem(*d));
+    foreach(const Device * d, devices)
+    listDevices().addItem(new ListDeviceWidgetItem(*d));
 }
 
 void ListDevices::on_m_ListDevices_itemSelectionChanged()
 {
-	if (listDevices().selectedItems().size() == 1)
-	{
-		ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(listDevices().selectedItems()[0]);
+    if (listDevices().selectedItems().size() == 1) {
+        ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(listDevices().selectedItems()[0]);
 
-		if (item != NULL)
-			emit selectionChanged(item->deviceNode);
-	}
+        if (item != NULL)
+            emit selectionChanged(item->deviceNode);
+    }
 }
 
 void ListDevices::on_m_ListDevices_customContextMenuRequested(const QPoint& pos)
 {
-	emit contextMenuRequested(listDevices().viewport()->mapToGlobal(pos));
+    emit contextMenuRequested(listDevices().viewport()->mapToGlobal(pos));
 }
 
 void ListDevices::on_m_ListDevices_itemDoubleClicked(QListWidgetItem* list_item)
 {
-	ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(list_item);
+    ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(list_item);
 
-	if (item != NULL)
-		emit deviceDoubleClicked(item->deviceNode);
+    if (item != NULL)
+        emit deviceDoubleClicked(item->deviceNode);
 }
 
 bool ListDevices::setSelectedDevice(const QString& device_node)
 {
-	QList<QListWidgetItem*> items = listDevices().findItems(device_node, Qt::MatchContains);
+    QList<QListWidgetItem*> items = listDevices().findItems(device_node, Qt::MatchContains);
 
-	if (items.size() > 0)
-	{
-		listDevices().setCurrentItem(items[0]);
-		return true;
-	}
+    if (items.size() > 0) {
+        listDevices().setCurrentItem(items[0]);
+        return true;
+    }
 
-	return false;
+    return false;
 }
