@@ -19,49 +19,55 @@
 
 #define TREELOG__H
 
-#include "util/libpartitionmanagerexport.h"
+#include "util/libpartitionmanagerguiexport.h"
 
 #include "ui_treelogbase.h"
 
-#include "util/globallog.h"
+#include <kpmcore/util/globallog.h>
 
 #include <QWidget>
 
 class QTreeWidget;
 
 /** A tree for formatted log output.
-	@author Volker Lanz <vl@fidra.de>
+    @author Volker Lanz <vl@fidra.de>
 */
-class LIBPARTITIONMANAGERPRIVATE_EXPORT TreeLog: public QWidget, public Ui::TreeLogBase
+class LIBKPMGUI_EXPORT TreeLog: public QWidget, public Ui::TreeLogBase
 {
-	Q_OBJECT
-	Q_DISABLE_COPY(TreeLog)
+    Q_OBJECT
+    Q_DISABLE_COPY(TreeLog)
 
-	public:
-		TreeLog(QWidget* parent = NULL);
-		~TreeLog();
+public:
+    TreeLog(QWidget* parent = NULL);
+    ~TreeLog();
 
-	Q_SIGNALS:
-		void contextMenuRequested(const QPoint&);
+Q_SIGNALS:
+    void contextMenuRequested(const QPoint&);
 
-	public:
-		void init();
+public:
+    void init();
 
-	protected Q_SLOTS:
-		void onNewLogMessage(Log::Level logLevel, const QString& s);
-		void onHeaderContextMenu(const QPoint& pos);
-		void onClearLog();
-		void onSaveLog();
-		void on_m_TreeLog_customContextMenuRequested(const QPoint& pos);
+protected Q_SLOTS:
+    void onNewLogMessage(Log::Level logLevel, const QString& s);
+    void onHeaderContextMenu(const QPoint& pos);
+    void onClearLog();
+    void onSaveLog();
+    void on_m_TreeLog_customContextMenuRequested(const QPoint& pos);
 
-	protected:
-		QTreeWidget& treeLog() { Q_ASSERT(m_TreeLog); return *m_TreeLog; }
-		const QTreeWidget& treeLog() const { Q_ASSERT(m_TreeLog); return *m_TreeLog; }
+protected:
+    QTreeWidget& treeLog() {
+        Q_ASSERT(m_TreeLog);
+        return *m_TreeLog;
+    }
+    const QTreeWidget& treeLog() const {
+        Q_ASSERT(m_TreeLog);
+        return *m_TreeLog;
+    }
 
-		void loadConfig();
-		void saveConfig() const;
+    void loadConfig();
+    void saveConfig() const;
 
-	private:
+private:
 };
 
 #endif
